{%     endfor %}
{%   endif %}
{% endmacro %}
{% macro match_iterate_block(match_list) %}
{%   if match_list | type_debug == "list" %}
{%     for match in match_list %}
{{       match_block(match) -}}
{%     endfor %}
{%   else %}
{{     match_block(match_list) -}}
{%   endif %}
{% endmacro %}
